Utility to convert fgsea/ultragsea style results to 'gseaResult' object compatible with clusterProfiler and enrichplot functions. Using this function you can use all plotting functions from enrichplot.
Source:R/utils.R
makeGseaResult.RdUtility to convert fgsea/ultragsea style results to 'gseaResult' object compatible with clusterProfiler and enrichplot functions. Using this function you can use all plotting functions from enrichplot.